Enum SqliteDiscoveryError
pub enum SqliteDiscoveryError {
ParseIntError,
ParseFloatError,
IndexNotFound(String),
SqlxError(SqlxError),
}Expand description
All the errors that can be encountered when using this module
Variants
ParseIntError
An error parsing a string from the result of an SQLite query into an rust-language integer
ParseFloatError
An error parsing a string from the result of an SQLite query into an rust-language float
IndexNotFound(String)
The target index was not found
SqlxError(SqlxError)
The error as defined in SqlxError